Measures the association between a categorical variable and a continuous variable, for each category of a group variable
assoc.catcont.by(x, y, by, weights = NULL,
na.rm.cat = FALSE, na.value.cat = "NA", na.rm.cont = FALSE,
nperm = NULL, distrib = "asympt", digits = 3)A list of items, one for each category of the group variable. Each item is a list with the following elements :
summary statistics (mean, median, etc.) of the continuous variable for each level of the categorical variable
eta-squared between the two variables
p-value from a permutation (i.e. non-parametric) test of independence
point biserial correlation between the two variables, for each level of the categorical variable
permutation p-value of the correlation between the two variables, for each level of the categorical variable
test-values as proposed by Lebart et al (1984)
p-values corresponding to the test-values
factor : the categorical variable
numeric vector : the continuous variable
factor : the group variable
numeric vector of weights. If NULL (default), uniform weights (i.e. all equal to 1) are used.
logical, indicating whether NA values in the categorical variable (i.e. x) should be silently removed before the computation proceeds. If FALSE (default), an additional level is added to the categorical variable (see na.value.cat argument).
character. Name of the level for NA category. Default is "NA". Only used if na.rm.cat = FALSE.
logical, indicating whether NA values in the continuous variable (i.e. y) should be silently removed before the computation proceeds. Default is FALSE.
numeric. Number of permutations for the permutation test of independence. If NULL (default), no permutation test is performed.
the null distribution of permutation test of independence can be approximated by its asymptotic distribution ("asympt", default) or via Monte Carlo resampling ("approx".
integer. The number of digits (default is 3).
Nicolas Robette
Rakotomalala R., 'Comprendre la taille d'effet (effect size)', [http://eric.univ-lyon2.fr/~ricco/cours/slides/effect_size.pdf]
Lebart L., Morineau A. and Warwick K., 1984, *Multivariate Descriptive Statistical Analysis*, John Wiley and sons, New-York.
assoc.catcont, assoc.twocat, assoc.twocont, assoc.yx, condesc,
catdesc, darma
data(Movies)
with(Movies, assoc.catcont.by(Country, Budget, ArtHouse, nperm = 10))
Run the code above in your browser using DataLab