powered by
Displays of scatter plot and adds a smoothing line, using ggplot2.
ggassoc_scatter(data, mapping, na.rm = FALSE, axes.labs = TRUE, ticks.labs = TRUE, text.size = 3)
a ggplot object
dataset to use for plot
aesthetic being used. It must specify x and y.
logical, indicating whether NA values should be silently removed before the computation proceeds. Default is FALSE.
Whether to display the labels of the axes, i.e. the names of x and y. Default is TRUE.
Whether to display the labels of the categories of x and y. Default is TRUE.
Size of the association measure. If NULL, the text is not added to the plot.
Nicolas Robette
Kendall's tau rank correlation between x and y is displayed in upper-left corner of the plot.
Smoothing is performed with gam.
This function can be used as a high-level plot with ggduo and ggpairs functions of the GGally package.
ggduo
ggpairs
GGally
assoc.twocont, condesc, assoc.yx, darma, ggpairs
assoc.twocont
condesc
assoc.yx
darma
data(Movies) ggassoc_scatter(Movies, mapping = ggplot2::aes(x = Budget, y = Critics))
Run the code above in your browser using DataLab